@@ -472,60 +472,10 @@ IDLPassXlate::union_create_members (const IDLUnion &un)
 {
 	for (IDLUnion::const_iterator i = un.begin (); i != un.end (); ++i)
 	{
-		const IDLCaseStmt &case_stmt = static_cast<const IDLCaseStmt&> (**i);
+
+		const IDLCaseStmt &case_stmt = dynamic_cast<const IDLCaseStmt&> (**i);
 		const IDLMember   &member = case_stmt.get_member ();
-
-		const string member_cpp_type = member.getType ()->get_cpp_member_typename ();
-		const string member_name = member.get_cpp_identifier ();
-		
-		// Getter accessor
-		m_header << indent << member_cpp_type << " "
-			 << member_name << " () const;" << endl;
-
-		m_module << mod_indent << member_cpp_type << " "
-			 << un.get_cpp_method_prefix () << "::" << member_name
-			 << " () const" << endl
-			 << mod_indent++ << "{" << endl;
-
-		m_module << mod_indent << member_cpp_type << " _ret;" << endl;
-
-		if (un.is_fixed ())
-			member.getType ()->member_unpack_from_c (
-				m_module, mod_indent, "_ret", "m_target._u." + member_name);
-		else
-			member.getType ()->member_unpack_from_c (
-				m_module, mod_indent, "_ret", "m_target->_u." + member_name);
-			
-		m_module << mod_indent << "return _ret;" << endl;
-		m_module << --mod_indent << "}" << endl << endl;
-		
-
-		// Setter accessor
-		string discr_val;
-		if (case_stmt.isDefault ())
-			discr_val = un.get_discriminator_default_value ();
-		else
-			discr_val = *(case_stmt.labelsBegin());
-		
-		m_header << indent << "void " << member_name
-			 << " (" << member_cpp_type << " val);" << endl << endl;
-		
-		m_module << mod_indent << "void "
-			 << un.get_cpp_method_prefix () << "::" << member_name
-			 << " (" << member_cpp_type << " val)" << endl
-			 << mod_indent++ << "{" << endl;
-
-		m_module << mod_indent << "_clear_member ();" << endl;
-		m_module << mod_indent << "_d (" << discr_val << ");" << endl;
-
-		if (un.is_fixed ())
-			member.getType ()->member_pack_to_c (
-				m_module, mod_indent, "val", "m_target._u." + member_name);
-		else
-			member.getType ()->member_pack_to_c (
-				m_module, mod_indent, "val", "m_target->_u." + member_name);
-
-		m_module << --mod_indent << "}" << endl << endl;
+		member.getType ()->create_union_accessors(un, case_stmt, m_header, indent, m_module, mod_indent);
 	}
 }
 
@@ -690,19 +640,25 @@ IDLPassXlate::doEnum (IDL_tree  node,
 {
 	IDLEnum &idlEnum = (IDLEnum &) *scope.getItem(node);
 
-	m_header << indent << "enum " << idlEnum.get_cpp_identifier () << endl
-		 << indent++ << "{" << endl;
+
+	m_header << indent << "typedef  "
+		<< idlEnum.get_c_typename() << ' '
+		<< idlEnum.get_cpp_identifier () << ";\n";
+
+	string prefix =
+		(scope.scope_implementation() == IDLScopeImplementation::by_type) ?
+			"static" :
+			"";
 
 	for (IDLEnum::const_iterator i = idlEnum.begin ();
 	     i != idlEnum.end (); i++)
 	{
-		m_header << indent << (*i)->get_cpp_identifier ()
-			 << ", " << endl;
+		m_header << indent << prefix << ' '
+			<< idlEnum.get_cpp_identifier() << " const "
+			<< (*i)->get_cpp_identifier() << " = "
+			<< (*i)->get_c_typename() << ";\n ";
 	}
 	
-	m_header << --indent << "};" << endl << endl; 
-
-	
 	m_header << indent << "typedef " << idlEnum.get_cpp_identifier () << "& "
 		 << idlEnum.get_cpp_identifier () << "_out;" << endl << endl;
 
@@ -735,7 +691,7 @@ IDLPassXlate::doConstant (IDL_tree  node,
 	if (cns.getTopLevelInterface ())
 		m_header  << "static ";
 
-	cns.getType ()->const_decl_write (m_header, indent,
+	cns.getType ()->const_decl_write (m_header, m_module, scope, indent,
 					  cns.get_cpp_identifier (),
 					  cns.getValue ());
 }
@@ -1323,45 +1279,6 @@ void IDLPassXlate::element_write_typecode (const IDLElement &element, bool class
 }
 
 
-// IDLWriteArrayProps -------------------------------------------------------
-void IDLWriteArrayProps::run()
-{
-	string array_id = m_dest.get_cpp_typename ();
-	string slice_id = array_id + "_slice";
-	string props_id = m_dest.get_cpp_identifier () + "Props";
-
-	int length = 1;
-	for (IDLArray::const_iterator i = m_array.begin ();
-	     i != m_array.end (); i++)
-	{
-		length *= *i;
-	}
-
-	// Alloc
-	m_header << indent << "template<>" << endl;
-	m_header << indent << "inline " << slice_id + " * " << props_id << "::alloc ()" << endl
-		 << indent++ << "{" << endl;
-	m_header << indent << "return " << array_id + "_alloc ();" << endl;
-	m_header << --indent << "}" << endl << endl;
-
-	// Free
-	m_header << indent << "template<>" << endl;
-	m_header << indent << "inline void " << props_id << "::free ("
-		 << slice_id << " * target)" << endl
-		 << indent++ << "{" << endl;
-	m_header << indent << array_id + "_free (target);" << endl;
-	m_header << --indent << "}" << endl << endl;
-
-	// Copy
-	m_header << indent << "template<>" << endl;
-	m_header << indent << "inline void " << props_id << "::copy ("
-		 << slice_id << " * dest, "
-		 << "const " << slice_id << " * source)" << endl
-		 << indent++ << "{" << endl;
-	m_header << indent << array_id + "_copy (dest, source);" << endl;
-	m_header << --indent << "}" << endl << endl;
-}
-
 // IDLWriteAnyFuncs -------------------------------------------------------
 IDLWriteAnyFuncs::IDLWriteAnyFuncs (IDLCompilerState &state,
 				    IDLOutputPass    &pass):
