@@ -322,35 +322,9 @@ IDLAny::get_c_member_typename (const IDLTypedef *active_typedef) const
 	return "CORBA_any";
 }
 
-string
-IDLAny::get_seq_typename (unsigned int      length,
-			  const IDLTypedef *active_typedef) const
-{
-	string retval;
-	string cpp_type = active_typedef ?
-		active_typedef->get_cpp_typename () : get_cpp_typename ();
-	
-	char *tmp = 0;
-	if (length)
-		tmp = g_strdup_printf (IDL_IMPL_NS "::CompoundBoundedSeq< %s, %d>",
-				       cpp_type.c_str (), length);
-	else
-		tmp = g_strdup_printf (IDL_IMPL_NS "::CompoundUnboundedSeq< %s >",
-				       cpp_type.c_str ());
-	
-	retval = tmp;
-	g_free (tmp);
-	
-	return retval;
-}
-
 string
 IDLAny::member_decl_arg_get (const IDLTypedef *active_typedef) const
 {
-#warning "WRITE ME"
-	
-	cerr << "Any::member_decl_arg_get" << endl;
-	
 	return "const CORBA::Any&";
 }
 
@@ -360,17 +334,7 @@ IDLAny::member_impl_arg_copy (ostream          &ostr,
 			      const string     &cpp_id,
 			      const IDLTypedef *active_typedef) const
 {
-#warning "WRITE ME"
-	cerr << "Any::member_impl_arg_copy" << endl;
-}
-
-void
-IDLAny::member_init_cpp (ostream          &ostr,
-			 Indent           &indent,
-			 const string     &cpp_id,
-			 const IDLTypedef *active_typedef) const
-{
-#warning "WRITE ME"
+	ostr << indent << cpp_id << " = _par_" << cpp_id << ';' << endl;
 }
 
 void
@@ -380,6 +344,8 @@ IDLAny::member_init_c (ostream          &ostr,
 		       const IDLTypedef *active_typedef) const
 {
 #warning "WRITE ME"
+	std::cerr << "IDLAny::member_init_c\n";
+	ostr << "// IDLAny::member_init_c\n";
 }
 
 void
@@ -389,10 +355,8 @@ IDLAny::member_pack_to_c (ostream          &ostr,
 			  const string     &c_id,
 			  const IDLTypedef *active_typedef) const
 {
-#if 0
-	ostr << indent << "CORBA_any__copy (" << c_id
+	ostr << indent << "CORBA_any__copy (&" << c_id
 	     << ", " << cpp_id << "._orbitcpp_cobj ());" << endl;
-#endif
 }
 
 void
@@ -402,8 +366,6 @@ IDLAny::member_unpack_from_c  (ostream          &ostr,
 			       const string     &c_id,
 			       const IDLTypedef *active_typedef) const
 {
-#if 0
-	ostr << indent << cpp_id << ".copy ("
-	     << "CORBA::Any::_orbitcpp_wrap (" << c_id << "));" << endl;
-#endif
+	ostr << indent << "CORBA_any__copy ("
+	     << cpp_id << "._orbitcpp_cobj(), &" << c_id << ");\n";
 }
