@@ -34,7 +34,12 @@
 #include "IDLCompoundSeqElem.h"
 //#include "language.h"
 
-class IDLUnion: public IDLScope, public IDLCompoundSeqElem
+class IDLUnion :
+	public IDLScope,
+	public IDLCompoundSeqElem,
+	public IDLScopeTypeImplementation,
+	protected IDLDefaultConstructed,
+	public IDLReferentUnionable
 {
 	const IDLUnionDiscriminator &m_discriminator;
 
@@ -155,11 +160,6 @@ public:
 				   const IDLTypedef *active_typedef = 0) const;
 	
 	// Initialization
-	void member_init_cpp (ostream          &ostr,
-			      Indent           &indent,
-			      const string     &cpp_id,
-			      const IDLTypedef *active_typedef = 0) const;
-	
 	void member_init_c   (ostream          &ostr,
 			      Indent           &indent,
 			      const string     &c_id,
